@@ -8,8 +8,7 @@ class Brain:
     def __init__(self, mode=0):
         self.config = ConfigEnum()
         self.modeSwitcher = {
-            0: self.config.get("CNN_DEFAULT_MODEL"),
-            1: self.config.get("CNN_30MIN_MODEL")
+            0: self.config.get("CNN_DEFAULT_MODEL")
         }
         self.model = None
         self.init(self.modeSwitcher[mode])
